@@ -183,12 +183,12 @@ class ContentExtractor(object):
             if date_str:
                 try:
                     return date_parser(date_str)
-                except (ValueError, OverflowError, AttributeError):
+                except (ValueError, OverflowError, AttributeError, TypeError):
                     # near all parse failures are due to URL dates without a day
                     # specifier, e.g. /2014/04/
                     return None
 
-        date_match = re.search(urls.DATE_REGEX, url)
+        date_match = re.search(urls.STRICT_DATE_REGEX, url)
         if date_match:
             date_str = date_match.group(0)
             datetime_obj = parse_date_str(date_str)
